@@ -2,14 +2,34 @@
 Yaco
 ----
 
-Yaco provides a `dict` like structure that can be serialized to & from `yaml <http://www.yaml.org/>`_ 
+Yaco provides a `dict` like structure that can be serialized to & from
+`yaml <http://www.yaml.org/>`_. Yaco objects behave as dictionaries
+but also allow attribute access (loosely based on this `recipe <
+http://code.activestate.com/recipes/473786/>`_). Sublevel dictionaries
+are automatically converted to Yaco objects, allowing sublevel
+attribute access, for example::
+
+    >>> x = Yaco()
+    >>> x.test = 1
+    >>> x.sub.test = 2
+    >>> x.sub.test
+    2
+
+Note that sub-dictionaries do not need to be initialized. This has as
+a consequence that requesting uninitialized items automatically return
+an empty Yaco object (inherited from a dictionary).
+
+Yaco can be `found <http://pypi.python.org/pypi/Yaco/0.1.1>`_ in the
+`Python package index <http://pypi.python.org/pypi/>`_ and is also
+part of the `Moa source distribution
+<https://github.com/mfiers/Moa/tree/master/lib/python/Yaco>`_
+
+
 """
 
 import os
 import yaml
 
-import moa.utils          
-
 class Yaco(dict):
     """
     Loosely based on http://code.activestate.com/recipes/473786/ (r1)
